# Telegram бот сбора статистики по данным из базы данных

В проекте реализована клиентская часть бота по сбору статистики на основе данных из базы данных, собранной на форуме dccomics.ru. Для разработки использовалась библиотека telethon.

#### Порядок запуска для локального тестирования:
- Развернуть виртуальное окружение
- Активировать виртуальное окружение /venv/Scripts/activate
- Установить зависимости проекта из файла requirements.txt
- Запустить проект командой: python main.py.